@@ -32,6 +32,6 @@ class RedisPool(BaseConnectionPool):
         except ImportError:
             raise Exception(f"redis is not exist,run:pip install redis==4.1.4")
         pool = redis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
-                                             password=self.conn_info.password,
+                                             password=self.conn_info.password, max_connections=self.conn_info.max_size,
                                              db=self.conn_info.db_name, encoding="utf-8", decode_responses=True)
         return pool
