@@ -7,13 +7,13 @@ from lesscode.utils.encryption_algorithm import AES
 
 
 def condition_by_like(find_condition, column, value):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if value:
         find_condition[column] = {"$regex": f".*{value}.*"}
 
 
 def condition_by_in(find_condition, column, param_list, is_object=False, _include=True, is_need_decrypt_oralce=False):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param_list:
         param_list = [i for i in param_list if i not in [None, "", "all"]]
         if len(param_list) > 0:
@@ -31,7 +31,7 @@ def condition_by_in(find_condition, column, param_list, is_object=False, _includ
 
 
 def condition_by_between(column, data_list, and_condition_list, is_contain_end=True, is_contain_start=True):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if data_list:
         if data_list[0]:
             if is_contain_start:
@@ -46,7 +46,7 @@ def condition_by_between(column, data_list, and_condition_list, is_contain_end=T
 
 
 def condition_by_eq(find_condition, column, param, _include=True):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     if param is not None and param != "":
         if _include is True:
             find_condition[column] = param
@@ -55,7 +55,7 @@ def condition_by_eq(find_condition, column, param, _include=True):
 
 
 def mongodb_sql_paging(page_size, page_num):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     limit = int(page_size)
     skip = (int(page_num) - 1) * int(page_size)
 
