@@ -3,7 +3,7 @@ from copy import deepcopy
 
 
 def get_value_from_dict(data: dict, key: str = None):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     value = deepcopy(data)
     if key:
         key_list = key.split(".")
@@ -17,12 +17,12 @@ def get_value_from_dict(data: dict, key: str = None):
 
 # 去空
 def eliminate_empty(list):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     return [x for x in list if x is not None]
 
 
 def dict2single_dict(source_dict: dict, parent_name: str = ""):
-    warnings.warn("此方法已弃用，不推荐使用", DeprecationWarning)
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     result = {}
     for k, v in source_dict.items():
         column_name = f"{parent_name}.{k}" if parent_name else k
